## Chargement des extensions ----------------------------------------
library(tidyverse)
library(readxl)

## Chargement des données -------------------------------------------
Parcs <- read_excel("Desktop/TP0/Parcs.xlsx")

## Recodage des données ---------------------------------------------
Parcs <- as_tibble(Parcs)
Parcs$I <- as.numeric(Parcs$I)
Parcs$Parc <-factor(Parcs$Parc)

## Exemples des verbes d'actions ------------------------------------
# Les données du parcs P1 rangées dans le tibble P1
P1<-Parcs %>%
  filter(Parc=="P1")

# Ajout d'une colonne pour la puissance produite (tension de 20kV)
Parcs <- Parcs %>%
  mutate(Puissance=I*20000)

# A déterminer
Parcs %>%
  filter(Mois=="janvier" | Mois=="février") %>%
  filter(Puissance>220000 & Puissance<=400000) %>%
  select(-I) %>%
  arrange(desc(Puissance))

# Grouper par mois et sélectionner la puissance la plus grande
Parcs %>%
  group_by(Mois) %>%
  filter(Puissance==max(Puissance,na.rm=TRUE))

#
Parcs %>%
  group_by(Mois) %>%
  summarise(Pmax=max(Puissance,na.rm=TRUE),
            Pmin=min(Puissance,na.rm=TRUE),
            Pmoy=mean(Puissance,na.rm=TRUE),
            Pmed=median(Puissance,na.rm=TRUE))

#
Parcs %>%
  group_by(Parc) %>%
  summarise(Psum=sum(Puissance, na.rm=TRUE)) %>%
  ungroup() %>%
  mutate(Poucentage = Psum/sum(Psum)  * 100)

## Quelques graphiques avec la grammaire ggplot2 --------------------
# Nuages de points
ggplot(data = Parcs)+
  aes(x = NumMois, y = Puissance)+
  geom_point()

ggplot(data = Parcs)+
  aes(x = NumMois, y = Puissance, color = Parc, shape=Parc)+
  geom_point()

ggplot(data = Parcs)+
  geom_point(aes(x = NumMois, y = Puissance,color = Parc, shape=Parc))

ggplot(data = Parcs,aes(x = NumMois, y = Puissance,color = Parc, shape=Parc))+
  geom_point()

Graph_Nuage <-ggplot(data = Parcs)+
  aes(x = NumMois, y = Puissance/1E6, color = Parc, shape=Parc)+
  geom_point()

Graph_Nuage <- Graph_Nuage+
  ggtitle("La production électrique",subtitle = "par parcs") +
  xlab("Mois") +
  ylab("Puissance (MW)")+
  scale_x_continuous(breaks=seq(1,12,by=1))
Graph_Nuage

Graph_Nuage+theme_bw()
Graph_Nuage+theme_classic()
Graph_Nuage+theme_grey() #theme par défaut
Graph_Nuage+theme_minimal()

# Graphique en bâton
ggplot(data = Parcs,aes(x = NumMois, y = Puissance/1E6, fill=Parc))+
  geom_bar(stat="identity")+
  facet_wrap(~ Parc)+
  ggtitle("La production électrique",subtitle = "par parcs") +
  xlab("Mois") +
  ylab("Puissance (MW)")+
  scale_x_continuous(breaks=seq(1,12,by=1))+
  theme_bw()

# Graphique en bâton
ggplot(data = Parcs,aes(x = NumMois, y = Puissance/1E6, fill=Parc))+
  geom_bar(stat="identity")+
  facet_grid(. ~ Parc)+
  ggtitle("La production électrique",subtitle = "par parcs") +
  xlab("Mois") +
  ylab("Puissance (MW)")+
  scale_x_continuous(breaks=seq(1,12,by=1),limits=c(1,12))+
  theme_bw()+
  theme(legend.position="bottom")

# Boites à moustaches
Graph_moustaches <- ggplot(data = Parcs,aes(x = Parc, y = Puissance/1E6,
                                            color=Parc))+
  geom_boxplot()+
  geom_jitter(alpha = 0.2,show.legend=FALSE)+
  theme(legend.position="bottom")+
  theme_bw()+
  ylab("Puissance (MW)")
Graph_moustaches

ggsave("Graph_moustaches.pdf",plot = Graph_moustaches,width = 11, height = 8)
